@@ -324,6 +324,10 @@ struct InputAction {
 
     // Name of the built binary
     bin_name: String,
+
+    // How the script was called originally
+    #[cfg(unix)]
+    original_script_path: Option<String>,
 }
 
 impl InputAction {
@@ -370,6 +374,10 @@ impl InputAction {
                 Ok(cmd)
             } else {
                 let mut cmd = Command::new(&built_binary_path);
+                #[cfg(unix)]
+                if let Some(original_script_path) = &self.original_script_path {
+                    cmd.arg0(original_script_path);
+                }
                 cmd.args(script_args.iter());
                 Ok(cmd)
             }
@@ -527,6 +535,8 @@ fn decide_action_for(
         script: script_str,
         build_kind: args.build_kind,
         bin_name,
+        #[cfg(unix)]
+        original_script_path: args.script.clone(),
     })
 }
 
